@@ -14,7 +14,9 @@
 //! * Modify the rest of librsvg wherever the computed value of the property needs to be used.
 //! This is available in methods that take an argument of type [`ComputedValues`].
 
-use cssparser::{BasicParseErrorKind, ParseErrorKind, Parser, ParserInput, RuleBodyParser, ToCss};
+use cssparser::{
+    self, BasicParseErrorKind, ParseErrorKind, Parser, ParserInput, RuleBodyParser, ToCss,
+};
 use markup5ever::{
     expanded_name, local_name, namespace_url, ns, ExpandedName, LocalName, QualName,
 };
